@@ -7,6 +7,7 @@ from django.db.models import Q
 from django.contrib.auth.decorators import login_required
 
 from models import Article, Tag
+from forms import CommentForm
 
 def list_baseview(request, article_qs, template="simpleblog/list_view.html"):
     return render_to_response(template,
@@ -23,6 +24,16 @@ def tag_view(request, url_key):
 
 def article_view(request, url_key, template="simpleblog/article.html"):
     article = get_object_or_404(Article, url_key=url_key)
+    comment_form = CommentForm(request.POST or None)
+    if comment_form.is_valid():
+        comment = comment_form.save(commit=False)
+        comment.article = article
+        comment.save()
+        return HttpResponseRedirect(reverse("simpleblog.article", args=[article.url_key], ))
+
     return render_to_response(template,
-        {"article":article, },
+        {
+            "article":article,
+            "comment_form": comment_form,
+        },
         context_instance=RequestContext(request))
\ No newline at end of file
